@@ -33,7 +33,7 @@
 # /usr/share/common-licenses/AGPL-3; if not, see
 # <https://www.gnu.org/licenses/>.
 
-from __future__ import annotations, print_function
+from __future__ import annotations
 
 import argparse
 import sys
@@ -120,7 +120,7 @@ def get_writable_udm(binddn: str | None = None, bindpwdfile: str | None = None)
         try:
             with open(bindpwdfile) as f:
                 bindpwd = f.read().strip()
-        except IOError as err:
+        except OSError as err:
             error('Could not open "bindpwdfile" "%s": %s' % (bindpwdfile, err))
         ucr = ConfigRegistry()
         ucr.load()
